==> aspose-barcode-cloud-20.8.0.tar.gz: aspose-barcode-cloud-20.8.0/aspose_barcode_cloud/__init__.py <==
# coding: utf-8

# flake8: noqa

"""

    Copyright (c) 2020 Aspose.BarCode for Cloud

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.

"""


from __future__ import absolute_import

# import apis into sdk package
from aspose_barcode_cloud.api.barcode_api import BarcodeApi
from aspose_barcode_cloud.api.file_api import FileApi
from aspose_barcode_cloud.api.folder_api import FolderApi
from aspose_barcode_cloud.api.storage_api import StorageApi

# import ApiClient
from aspose_barcode_cloud.api_client import ApiClient
from aspose_barcode_cloud.configuration import Configuration

# import models into sdk package
from aspose_barcode_cloud.models.australian_post_params import AustralianPostParams
from aspose_barcode_cloud.models.auto_size_mode import AutoSizeMode
from aspose_barcode_cloud.models.available_graphics_unit import AvailableGraphicsUnit
from aspose_barcode_cloud.models.aztec_params import AztecParams
from aspose_barcode_cloud.models.aztec_symbol_mode import AztecSymbolMode
from aspose_barcode_cloud.models.bar_code_error_response import BarCodeErrorResponse
from aspose_barcode_cloud.models.barcode_response import BarcodeResponse
from aspose_barcode_cloud.models.barcode_response_list import BarcodeResponseList
from aspose_barcode_cloud.models.border_dash_style import BorderDashStyle
from aspose_barcode_cloud.models.caption_params import CaptionParams
from aspose_barcode_cloud.models.checksum_validation import ChecksumValidation
from aspose_barcode_cloud.models.codabar_checksum_mode import CodabarChecksumMode
from aspose_barcode_cloud.models.codabar_params import CodabarParams
from aspose_barcode_cloud.models.codabar_symbol import CodabarSymbol
from aspose_barcode_cloud.models.codablock_params import CodablockParams
from aspose_barcode_cloud.models.code16_k_params import Code16KParams
from aspose_barcode_cloud.models.code_location import CodeLocation
from aspose_barcode_cloud.models.coupon_params import CouponParams
from aspose_barcode_cloud.models.customer_information_interpreting_type import CustomerInformationInterpretingType
from aspose_barcode_cloud.models.data_bar_params import DataBarParams
from aspose_barcode_cloud.models.data_matrix_ecc_type import DataMatrixEccType
from aspose_barcode_cloud.models.data_matrix_encode_mode import DataMatrixEncodeMode
from aspose_barcode_cloud.models.data_matrix_params import DataMatrixParams
from aspose_barcode_cloud.models.decode_barcode_type import DecodeBarcodeType
from aspose_barcode_cloud.models.disc_usage import DiscUsage
from aspose_barcode_cloud.models.dot_code_params import DotCodeParams
from aspose_barcode_cloud.models.eci_encodings import ECIEncodings
from aspose_barcode_cloud.models.enable_checksum import EnableChecksum
from aspose_barcode_cloud.models.encode_barcode_type import EncodeBarcodeType
from aspose_barcode_cloud.models.error import Error
from aspose_barcode_cloud.models.error_details import ErrorDetails
from aspose_barcode_cloud.models.file_versions import FileVersions
from aspose_barcode_cloud.models.files_list import FilesList
from aspose_barcode_cloud.models.files_upload_result import FilesUploadResult
from aspose_barcode_cloud.models.font_mode import FontMode
from aspose_barcode_cloud.models.font_params import FontParams
from aspose_barcode_cloud.models.font_style import FontStyle
from aspose_barcode_cloud.models.generator_params import GeneratorParams
from aspose_barcode_cloud.models.generator_params_list import GeneratorParamsList
from aspose_barcode_cloud.models.itf14_border_type import ITF14BorderType
from aspose_barcode_cloud.models.itf_params import ITFParams
from aspose_barcode_cloud.models.maxi_code_params import MaxiCodeParams
from aspose_barcode_cloud.models.object_exist import ObjectExist
from aspose_barcode_cloud.models.padding import Padding
from aspose_barcode_cloud.models.patch_code_params import PatchCodeParams
from aspose_barcode_cloud.models.patch_format import PatchFormat
from aspose_barcode_cloud.models.pdf417_compaction_mode import Pdf417CompactionMode
from aspose_barcode_cloud.models.pdf417_error_level import Pdf417ErrorLevel
from aspose_barcode_cloud.models.pdf417_params import Pdf417Params
from aspose_barcode_cloud.models.postal_params import PostalParams
from aspose_barcode_cloud.models.preset_type import PresetType
from aspose_barcode_cloud.models.qr_encode_mode import QREncodeMode
from aspose_barcode_cloud.models.qr_encode_type import QREncodeType
from aspose_barcode_cloud.models.qr_error_level import QRErrorLevel
from aspose_barcode_cloud.models.qr_version import QRVersion
from aspose_barcode_cloud.models.qr_params import QrParams
from aspose_barcode_cloud.models.reader_params import ReaderParams
from aspose_barcode_cloud.models.region_point import RegionPoint
from aspose_barcode_cloud.models.result_image_info import ResultImageInfo
from aspose_barcode_cloud.models.storage_exist import StorageExist
from aspose_barcode_cloud.models.storage_file import StorageFile
from aspose_barcode_cloud.models.text_alignment import TextAlignment
from aspose_barcode_cloud.models.file_version import FileVersion

==> aspose-barcode-cloud-20.11.0.tar.gz: aspose-barcode-cloud-20.11.0/aspose_barcode_cloud/__init__.py <==
# coding: utf-8

# flake8: noqa

"""

    Copyright (c) 2020 Aspose.BarCode for Cloud

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.

"""


from __future__ import absolute_import

# import apis into sdk package
from aspose_barcode_cloud.api.barcode_api import BarcodeApi
from aspose_barcode_cloud.api.file_api import FileApi
from aspose_barcode_cloud.api.folder_api import FolderApi
from aspose_barcode_cloud.api.storage_api import StorageApi

# import ApiClient
from aspose_barcode_cloud.api_client import ApiClient
from aspose_barcode_cloud.configuration import Configuration

# import models into sdk package
from aspose_barcode_cloud.models.api_error import ApiError
from aspose_barcode_cloud.models.api_error_response import ApiErrorResponse
from aspose_barcode_cloud.models.australian_post_params import AustralianPostParams
from aspose_barcode_cloud.models.auto_size_mode import AutoSizeMode
from aspose_barcode_cloud.models.available_graphics_unit import AvailableGraphicsUnit
from aspose_barcode_cloud.models.aztec_params import AztecParams
from aspose_barcode_cloud.models.aztec_symbol_mode import AztecSymbolMode
from aspose_barcode_cloud.models.barcode_response import BarcodeResponse
from aspose_barcode_cloud.models.barcode_response_list import BarcodeResponseList
from aspose_barcode_cloud.models.border_dash_style import BorderDashStyle
from aspose_barcode_cloud.models.caption_params import CaptionParams
from aspose_barcode_cloud.models.checksum_validation import ChecksumValidation
from aspose_barcode_cloud.models.codabar_checksum_mode import CodabarChecksumMode
from aspose_barcode_cloud.models.codabar_params import CodabarParams
from aspose_barcode_cloud.models.codabar_symbol import CodabarSymbol
from aspose_barcode_cloud.models.codablock_params import CodablockParams
from aspose_barcode_cloud.models.code16_k_params import Code16KParams
from aspose_barcode_cloud.models.code_location import CodeLocation
from aspose_barcode_cloud.models.coupon_params import CouponParams
from aspose_barcode_cloud.models.customer_information_interpreting_type import CustomerInformationInterpretingType
from aspose_barcode_cloud.models.data_bar_params import DataBarParams
from aspose_barcode_cloud.models.data_matrix_ecc_type import DataMatrixEccType
from aspose_barcode_cloud.models.data_matrix_encode_mode import DataMatrixEncodeMode
from aspose_barcode_cloud.models.data_matrix_params import DataMatrixParams
from aspose_barcode_cloud.models.decode_barcode_type import DecodeBarcodeType
from aspose_barcode_cloud.models.disc_usage import DiscUsage
from aspose_barcode_cloud.models.dot_code_params import DotCodeParams
from aspose_barcode_cloud.models.eci_encodings import ECIEncodings
from aspose_barcode_cloud.models.enable_checksum import EnableChecksum
from aspose_barcode_cloud.models.encode_barcode_type import EncodeBarcodeType
from aspose_barcode_cloud.models.error import Error
from aspose_barcode_cloud.models.error_details import ErrorDetails
from aspose_barcode_cloud.models.file_versions import FileVersions
from aspose_barcode_cloud.models.files_list import FilesList
from aspose_barcode_cloud.models.files_upload_result import FilesUploadResult
from aspose_barcode_cloud.models.font_mode import FontMode
from aspose_barcode_cloud.models.font_params import FontParams
from aspose_barcode_cloud.models.font_style import FontStyle
from aspose_barcode_cloud.models.generator_params import GeneratorParams
from aspose_barcode_cloud.models.generator_params_list import GeneratorParamsList
from aspose_barcode_cloud.models.itf14_border_type import ITF14BorderType
from aspose_barcode_cloud.models.itf_params import ITFParams
from aspose_barcode_cloud.models.maxi_code_params import MaxiCodeParams
from aspose_barcode_cloud.models.object_exist import ObjectExist
from aspose_barcode_cloud.models.padding import Padding
from aspose_barcode_cloud.models.patch_code_params import PatchCodeParams
from aspose_barcode_cloud.models.patch_format import PatchFormat
from aspose_barcode_cloud.models.pdf417_compaction_mode import Pdf417CompactionMode
from aspose_barcode_cloud.models.pdf417_error_level import Pdf417ErrorLevel
from aspose_barcode_cloud.models.pdf417_params import Pdf417Params
from aspose_barcode_cloud.models.postal_params import PostalParams
from aspose_barcode_cloud.models.preset_type import PresetType
from aspose_barcode_cloud.models.qr_encode_mode import QREncodeMode
from aspose_barcode_cloud.models.qr_encode_type import QREncodeType
from aspose_barcode_cloud.models.qr_error_level import QRErrorLevel
from aspose_barcode_cloud.models.qr_version import QRVersion
from aspose_barcode_cloud.models.qr_params import QrParams
from aspose_barcode_cloud.models.reader_params import ReaderParams
from aspose_barcode_cloud.models.region_point import RegionPoint
from aspose_barcode_cloud.models.result_image_info import ResultImageInfo
from aspose_barcode_cloud.models.storage_exist import StorageExist
from aspose_barcode_cloud.models.storage_file import StorageFile
from aspose_barcode_cloud.models.text_alignment import TextAlignment
from aspose_barcode_cloud.models.file_version import FileVersion
